@@ -41,6 +41,7 @@ namespace ConeProperty {
         // matrix valued
         Generators,
         ExtremeRays,
+        VerticesFloat,
         VerticesOfPolyhedron,
         SupportHyperplanes,
         HilbertBasis,
@@ -51,46 +52,52 @@ namespace ConeProperty {
         ExcludedFaces,
         OriginalMonoidGenerators,
         MaximalSubspace,
-        Equations, // new
-        Congruences, // new
+        Equations,
+        Congruences,
         //vector valued
         Grading,
         Dehomogenization,
         WitnessNotIntegrallyClosed,
+        GeneratorOfInterior,
         // Cardinalities
         TriangulationSize,
         // Integer valued,        
         TriangulationDetSum,
         ReesPrimaryMultiplicity,
-        GradingDenom, // new
-        UnitGroupIndex, // new
-        InternalIndex, // new
-        ExternalIndex, // new
+        GradingDenom,
+        UnitGroupIndex,
+        InternalIndex,
+        ExternalIndex,
         // rational valued
         Multiplicity,
+        Integral,
+        VirtualMultiplicity,
         // dimensions
         RecessionRank,
         AffineDim,
         ModuleRank,
-        Rank, // new
-        EmbeddingDim, // new      
+        Rank,
+        EmbeddingDim,      
         // boolean valued 
         IsPointed,
         IsDeg1ExtremeRays,
         IsDeg1HilbertBasis,
         IsIntegrallyClosed,
         IsReesPrimary,
-        IsInhomogeneous, // new        
+        IsInhomogeneous,
+        IsGorenstein,        
         // complex structures
         Triangulation,
-        HilbertSeries,
-        InclusionExclusionData,
-        StanleyDec,        
+        StanleyDec,
+        InclusionExclusionData,        
         ClassGroup,        
         IntegerHull,
         ConeDecomposition,
+        HilbertSeries,
         HilbertQuasiPolynomial,
-                //
+        WeightedEhrhartSeries,
+        WeightedEhrhartQuasiPolynomial,        
+        //
         // integer type for computations
         //
         BigInt,
@@ -102,18 +109,24 @@ namespace ConeProperty {
         BottomDecomposition,
         NoBottomDec,       
         DualMode,
-        PrimalMode, //new
-        Symmetrize, // new
-        NoSymmetrization, // new
-        NoNestedTri, // new
+        PrimalMode,
+        Projection,
+        ProjectionFloat,
+        NoProjection,
+        Symmetrize,
+        NoSymmetrization,
+        NoSubdivision,
+        NoNestedTri, // synonym for NoSubdivision
         KeepOrder,
         HSOP,
+        NoPeriodBound,
+        SCIP,
         //
         // checking properties of already computed data
         // (cannot be used as a computation goal)
         //
-        IsTriangulationNested,  //new
-        IsTriangulationPartial,  //new
+        IsTriangulationNested,
+        IsTriangulationPartial,
         
         EnumSize // this has to be the last entry, to get the number of entries in the enum
     }; // remember to change also the string conversion function if you change this enum
@@ -151,9 +164,10 @@ public:
     ConeProperties options();
 
     /* the following methods are used internally */
-    void set_preconditions();    // activate properties which are needed implicitly
+    void set_preconditions(bool inhomogeneous);    // activate properties which are needed implicitly
     void prepare_compute_options(bool inhomogeneous);
     void check_sanity(bool inhomogeneous);
+    void check_conflicting_variants();
 
     /* print it in a nice way */
     friend std::ostream& operator<<(std::ostream&, const ConeProperties&);
